Opinions - Delaware Courts - State of Delaware
Description: Court opinions from the Delaware Court system.

# Opinions and Orders

Please note: These electronic orders may contain computer-generated errors or other deviations from the official printed versions. In case of discrepancies between the print and electronic versions of orders, the print version controls. In case of discrepancies between the print and electronic versions of orders and any later official version of them, the later version controls.

Court:
Decision Date:
Search:

#### Court of Common Pleas Opinions and Orders 14 Opinions

Results per page

Parties/Caption | Date | File Number | Court | Type | Judicial Officer | Description
--- | --- | --- | --- | --- | --- | ---
Denise Duncan v JBS Construction LLC | 03/31/2016 | CPU6-14-000469 | Court of Common Pleas | Civil | Beauregard J. | Decision after Trial
McGinnis Commercial Real Estate Co. v. Andres Jankes | 03/29/2016 | CPU5-14-000701 | Court of Common Pleas | Civil | Rennie, J J. | Decision After Trial
Valory Shepperson v. State Farm Mutual Automobile Insurance Company | 03/28/2016 | CPU4-14-003863 | Court of Common Pleas | Civil | Rennie, J J. | Decision After Trial
Delaware Health and Social Services, Audit and Recovery Management Services v. Andrea L. Glazik | 03/14/2016 | CPU4-14-001527 | Court of Common Pleas | Civil | Smalls C.J. | Decision After Trial
State Farm Mutual Automobile Ins. Co. v. Morgan E. Dailey and Victor M. Restrepo-Rubio | 03/14/2016 | CPU4-14-002799 | Court of Common Pleas | Civil | Smalls C.J. | Order
State of Delaware v. Desmond Hopkins | 03/11/2016 | 1307009361 | Court of Common Pleas | Criminal | Danberg J. | Memorandum Opinion and Order on Defendant's Motion to Dismiss
Tiby Saunders-Gomez v. Rutledge Maintenance Corporation | 02/25/2016 | CPU4-13-003588 | Court of Common Pleas | Civil | Danberg J. | Memorandum Opinion and Order on Appellee's Request for Attorney's Fees
State of Delaware v. Rakiem Dumas | 02/22/2016 | 1412009796 | Court of Common Pleas | Criminal | Danberg J. | Memorandum Opinion and Order on Defendant's Motion for Reargument
State of Delaware vs. Donald Melvin, Lauri Larlham, Shaughn Graves, Ethel Melvin | 02/05/2016 | 1507023761/1507021781/1507021807/1507021736 | Court of Common Pleas | Criminal | Clark J. | Decision on Defendants' Motion to Compel
Angela L. DeFelice v. Catherine Nelson and Robert Langley | 02/01/2016 | CPU6-15-001621 | Court of Common Pleas | Civil | Clark J. | Order on Plaintiff/Appellant's Appeal From the JP Court
John Peach v. M & T Bank Corp., and Fannie Mae Corp. | 01/29/2016 | CPU6-15-001185 | Court of Common Pleas | Civil | Clark J. | Decision on Plaintiff's Motion for Reconsideration of Commissioner's Order and Appeal From Commissioner's Findings of Fact and Recommendations
Dario v. First Horizon Home Loan Corporation and Metlife Home Loans, LLC | 01/21/2016 | CPU4-15-003818 | Court of Common Pleas | Civil | Fraczkowski J. | Letter Opinion
State of Delaware v. Daniel Slaney | 01/20/2016 | 1407022138 | Court of Common Pleas | Criminal | Rennie J. | Memorandum Opinion and Order
State of Delaware v. John M. Hannon | 01/19/2016 | 1412007625 | Court of Common Pleas | Criminal | Danberg J. | Memorandum Opinion and Order on Defendant's Motion in Limine

* C.=Chancellor or Commissioner C.J.=Chief Justice or Chief Judge J.=Justice or Judge M.=Master P.J.=President Judge R.J.=Resident Judge V.C.=Vice Chancellor